@@ -2,7 +2,7 @@ from bergen.query import DelayedGQL
 
 
 CREATE_REPRESENTATION = DelayedGQL("""
-mutation Representation($sample: ID, $name: String!, $tags: [String], $variety: RepresentationVarietyInput!){
+mutation Representation($sample: ID, $name: String, $tags: [String], $variety: RepresentationVarietyInput){
   createRepresentation(sample: $sample, name: $name, tags: $tags, variety: $variety){
     name
     id
