@@ -1,11 +1,13 @@
-from grunnlag.gql.sample import CREATE_SAMPLE, FILTER_SAMPLE, GET_SAMPLE
-from grunnlag.gql.representation import CREATE_REPRESENTATION, GET_REPRESENTATION, UPDATE_REPRESENTATION, FILTER_REPRESENTATION
+from grunnlag.graphql.queries.representation import GET_REPRESENTATION, FILTER_REPRESENTATION
+from grunnlag.graphql.mutations.representation import CREATE_REPRESENTATION, UPDATE_REPRESENTATION
+from grunnlag.graphql.queries.sample import GET_SAMPLE, FILTER_SAMPLE
+from grunnlag.graphql.mutations.sample import CREATE_SAMPLE
 from grunnlag.managers import AsyncRepresentationManager, RepresentationManager
 from typing import List, Optional
 from bergen.types.model import ArnheimModel
 from bergen.schema import User
 from enum import Enum
-from grunnlag.extenders import Array, RepresentationPrettifier
+from grunnlag.extenders import Array
 try:
 	# python 3.8
 	from typing import ForwardRef
@@ -26,7 +28,7 @@ class RepresentationVariety(str, Enum):
 
 
 
-class Representation(RepresentationPrettifier, Array, ArnheimModel):
+class Representation(Array, ArnheimModel):
     id: Optional[int]
     name: Optional[str]
     package: Optional[str]
@@ -53,7 +55,7 @@ class Sample(ArnheimModel):
     id: Optional[int]
     representations: Optional[List[Representation]]
     creator: Optional[User]
-    experiment: Optional[Experiment]
+    experiments: Optional[List[Experiment]]
     name: Optional[str]
 
     class Meta:
@@ -69,7 +71,7 @@ class Experiment(ArnheimModel):
     description: Optional[str]
     descriptionLong: Optional[str]
     creator: Optional[User]
-    sampleSet: Optional[Sample]
+    samples: Optional[List[Sample]]
 
     class Meta:
         identifier = "experiment"
